@@ -1,27 +1,6 @@
-# -*- coding:utf-8 -*-
-#
-# MIT License
-#
-# Copyright (c) 2017 Mattia Verga <mattia.verga@tiscali.it>
-#
-# Permission is hereby granted, free of charge, to any person obtaining a copy
-# of this software and associated documentation files (the "Software"), to deal
-# in the Software without restriction, including without limitation the rights
-# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
-# copies of the Software, and to permit persons to whom the Software is
-# furnished to do so, subject to the following conditions:
-#
-# The above copyright notice and this permission notice shall be included in all
-# copies or substantial portions of the Software.
-#
-# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
-# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
-# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
-# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
-# SOFTWARE.
+# SPDX-FileCopyrightText: 2017 Mattia Verga <mattia.verga@tiscali.it>
 #
+# SPDX-License-Identifier: MIT
 
 from unittest import mock
 import pytest
@@ -482,7 +461,7 @@ class TestDsoMethods():
         obj2 = ongc.Dso('NGC6118')
 
         expected = (4.207483963913541, 2.9580416666666864, -2.9927499999999996)
-        assert ongc.getSeparation(obj1, obj2) == expected
+        np.testing.assert_allclose(ongc.getSeparation(obj1, obj2), expected)
 
     def test_get_separation_friendly(self):
         """Test that the calculated apparent angular separation between two objects
@@ -508,7 +487,7 @@ class TestDsoMethods():
         expectedNearest = 'IC1694, Galaxy in Cet'
         expectedNearestSeparation = 0.13726168561780452
 
-        assert type(neighbors) is list
+        assert isinstance(neighbors, list)
         assert len(neighbors) == expectedListLength
         assert str(neighbors[0][0]) == expectedNearest
         assert np.isclose(neighbors[0][1], expectedNearestSeparation)
@@ -522,7 +501,7 @@ class TestDsoMethods():
         expectedNearest = 'IC0058, Galaxy in Cet'
         expectedNearestSeparation = 0.4064105387726472
 
-        assert type(neighbors) is list
+        assert isinstance(neighbors, list)
         assert len(neighbors) == expectedListLength
         assert str(neighbors[0][0]) == expectedNearest
         assert np.isclose(neighbors[0][1], expectedNearestSeparation)
@@ -536,7 +515,7 @@ class TestDsoMethods():
         expectedNearest = 'NGC0016, Galaxy in Peg'
         expectedNearestSeparation = 0.1378555838270968
 
-        assert type(neighbors) is list
+        assert isinstance(neighbors, list)
         assert len(neighbors) == expectedListLength
         assert str(neighbors[0][0]) == expectedNearest
         assert np.isclose(neighbors[0][1], expectedNearestSeparation)
@@ -550,7 +529,7 @@ class TestDsoMethods():
         expectedNearest = 'NGC7802, Galaxy in Psc'
         expectedNearestSeparation = 0.7874886760327793
 
-        assert type(neighbors) is list
+        assert isinstance(neighbors, list)
         assert len(neighbors) == expectedListLength
         assert str(neighbors[0][0]) == expectedNearest
         assert np.isclose(neighbors[0][1], expectedNearestSeparation)
@@ -562,7 +541,7 @@ class TestDsoMethods():
         expectedNearest = 'NGC0533, Galaxy in Cet'
         expectedNearestSeparation = 0.24140243942744602
 
-        assert type(neighbors) is list
+        assert isinstance(neighbors, list)
         assert len(neighbors) == expectedListLength
         assert str(neighbors[0][0]) == expectedNearest
         assert np.isclose(neighbors[0][1], expectedNearestSeparation)
@@ -726,7 +705,7 @@ class TestDsoMethods():
         neighbors = ongc.getNeighbors(obj, 15)
         nearby_objects = ongc.nearby(objCoords, separation=15)
 
-        assert type(nearby_objects) is list
+        assert isinstance(nearby_objects, list)
         assert len(nearby_objects) == len(neighbors)+1
         assert str(nearby_objects[0][0]) == str(obj)
         assert nearby_objects[0][1] == 0
@@ -741,7 +720,7 @@ class TestDsoMethods():
         neighbors = ongc.getNeighbors('NGC521', 15, catalog='IC')
         nearby_objects = ongc.nearby(objCoords, separation=15, catalog='IC')
 
-        assert type(nearby_objects) is list
+        assert isinstance(nearby_objects, list)
         assert len(nearby_objects) == len(neighbors)
         assert str(nearby_objects[0][0]) == str(neighbors[0][0])
         assert nearby_objects[0][1] == neighbors[0][1]
@@ -875,7 +854,7 @@ class TestDatabaseIntegrity():
     def test_data_integrity(self):
         allObjects = ongc.listObjects()
         for item in allObjects:
-            assert type(item.id) is int
+            assert isinstance(item.id, int)
             assert item.type != ''
             if item.type != 'Nonexistent object':
                 # Be sure all objects have registered coordinates
